@@ -1,4 +1,7 @@
-# Main file for the tests. This file imports all the combined_test functions from all files.
+"""
+Main file for the tests. This file imports all the combined_test functions from all files.
+"""
+
 import unittest
 
 from binarycpython.tests.test_c_bindings import *
@@ -12,6 +15,7 @@ from binarycpython.tests.test_run_system_wrapper import *
 from binarycpython.tests.test_spacing_functions import *
 from binarycpython.tests.test_useful_funcs import *
 from binarycpython.tests.test_grid_options_defaults import *
+from binarycpython.tests.test_stellar_types import *
 
 if __name__ == "__main__":
     unittest.main()
