@@ -70,15 +70,23 @@ def remove_file(file: str, verbosity: int = 0) -> None:
 
         except FileNotFoundError as inst:
             print("Error while deleting file {}: {}".format(file, inst))
+    else:
+        verbose_print(
+            "File/directory {} doesn't exist. Can't remove it.".format(file),
+            verbosity,
+            1,
+        )
 
 
-def temp_dir() -> str:
+def temp_dir(*args: str) -> str:
     """
-    Function to return the path the custom logging library shared object
-    and script will be written to.
+    Function to create directory within the TMP directory of the filesystem
 
     Makes use of os.makedirs exist_ok which requires python 3.2+
 
+    Args:
+        function arguments: str input where each next input will be a child of the previous full_path. e.g. temp_dir('tests', 'grid') will become '/tmp/binary_c_python/tests/grid'
+
     Returns:
         the path of a subdirectory called binary_c_python in the TMP of the filesystem
     """
@@ -86,6 +94,11 @@ def temp_dir() -> str:
     tmp_dir = tempfile.gettempdir()
     path = os.path.join(tmp_dir, "binary_c_python")
 
+    # loop over the other paths if there are any:
+    if args:
+        for extra_dir in args:
+            path = os.path.join(path, extra_dir)
+
     #
     os.makedirs(path, exist_ok=True)
 
@@ -177,11 +190,29 @@ def return_binary_c_version_info(parsed: bool = False) -> Union[str, dict]:
         Either the raw string of binary_c or a parsed version of this in the form of a nested dictionary
     """
 
+    found_prev = False
+    if "BINARY_C_MACRO_HEADER" in os.environ:
+        # the envvar is already present. lets save that and put that back later
+        found_prev = True
+        prev_value = os.environ["BINARY_C_MACRO_HEADER"]
+
+    #
+    os.environ["BINARY_C_MACRO_HEADER"] = "macroxyz"
+
+    # Get version_info
     version_info = _binary_c_bindings.return_version_info().strip()
 
+    # parse if wanted
     if parsed:
         version_info = parse_binary_c_version_info(version_info)
 
+    # delete value
+    del os.environ["BINARY_C_MACRO_HEADER"]
+
+    # put stuff back if we found a previous one
+    if found_prev:
+        os.environ["BINARY_C_MACRO_HEADER"] = prev_value
+
     return version_info
 
 
@@ -189,6 +220,8 @@ def parse_binary_c_version_info(version_info_string: str) -> dict:
     """
     Function that parses the binary_c version info. Long function with a lot of branches
 
+    TODO: fix this function. stuff is missing: isotopes, macros, nucleosynthesis_sources
+
     Args:
         version_info_string: raw output of version_info call to binary_c
 
@@ -366,10 +399,23 @@ def parse_binary_c_version_info(version_info_string: str) -> dict:
     # TODO: filter a bit more.
 
     misc_dict = {}
+
+    # Filter out git revision
     git_revision = [el for el in cleaned if el.startswith("git revision")]
     misc_dict["git_revision"] = (
         git_revision[0].split("git revision ")[-1].replace('"', "")
     )
+    cleaned = cleaned - set(git_revision)
+
+    # filter out git url
+    git_url = [el for el in cleaned if el.startswith("git URL")]
+    misc_dict["git_url"] = git_url[0].split("git URL ")[-1].replace('"', "")
+    cleaned = cleaned - set(git_url)
+
+    # filter out version
+    version = [el for el in cleaned if el.startswith("Version")]
+    misc_dict["version"] = str(version[0].split("Version ")[-1])
+    cleaned = cleaned - set(version)
 
     git_branch = [el for el in cleaned if el.startswith("git branch")]
     misc_dict["git_branch"] = git_branch[0].split("git branch ")[-1].replace('"', "")
@@ -392,7 +438,7 @@ def parse_binary_c_version_info(version_info_string: str) -> dict:
         val = " is ".join(split[1:]).strip()
         misc_dict[key] = val
 
-    misc_dict["uncaught"] = "\n".join(cleaned)
+    misc_dict["uncaught"] = list(cleaned)
 
     version_info_dict["miscellaneous"] = misc_dict if misc_dict else None
     return version_info_dict
@@ -403,7 +449,7 @@ def parse_binary_c_version_info(version_info_string: str) -> dict:
 ########################################################
 
 
-def output_lines(output: str) -> str:
+def output_lines(output: str) -> list:
     """
     Function that outputs the lines that were recieved from the binary_c run, but now as an iterator.
 
@@ -532,7 +578,7 @@ def get_arg_keys() -> list:
         list of all the parameters that binary_c accepts (and has default values for, since we call get_defaults())
     """
 
-    return get_defaults().keys()
+    return list(get_defaults().keys())
 
 
 def filter_arg_dict(arg_dict: dict) -> dict:
@@ -579,7 +625,7 @@ def create_arg_string(
 
     # Whether to filter the arguments
     if filter_values:
-        arg_dict = filter_values(arg_dict)
+        arg_dict = filter_arg_dict(arg_dict)
 
     #
     keys = sorted(arg_dict.keys()) if sort else arg_dict.keys()
@@ -1124,19 +1170,35 @@ def merge_dicts(dict_1: dict, dict_2: dict) -> dict:
 
         # See whether the types are actually the same
         if not type(dict_1[key]) is type(dict_2[key]):
-            print(
-                "Error {} and {} are not of the same type and cannot be merged".format(
-                    dict_1[key], dict_2[key]
+            # Exceptions:
+            if (type(dict_1[key]) in [int, float]) and (
+                type(dict_2[key]) in [int, float]
+            ):
+                new_dict[key] = dict_1[key] + dict_2[key]
+
+            else:
+                print(
+                    "Error key: {} value: {} type: {} and key: {} value: {} type: {} are not of the same type and cannot be merged".format(
+                        key,
+                        dict_1[key],
+                        type(dict_1[key]),
+                        key,
+                        dict_2[key],
+                        type(dict_2[key]),
+                    )
                 )
-            )
-            raise ValueError
+                raise ValueError
 
         # Here we check for the cases that we want to explicitly catch. Ints will be added,
         # floats will be added, lists will be appended (though that might change) and dicts will be
         # dealt with by calling this function again.
         else:
             # ints
-            if isinstance(dict_1[key], int) and isinstance(dict_2[key], int):
+            # Booleans (has to be the type Bool, not just a 0 or 1)
+            if isinstance(dict_1[key], bool) and isinstance(dict_2[key], bool):
+                new_dict[key] = dict_1[key] or dict_2[key]
+
+            elif isinstance(dict_1[key], int) and isinstance(dict_2[key], int):
                 new_dict[key] = dict_1[key] + dict_2[key]
 
             # floats
@@ -1151,27 +1213,68 @@ def merge_dicts(dict_1: dict, dict_2: dict) -> dict:
             elif isinstance(dict_1[key], dict) and isinstance(dict_2[key], dict):
                 new_dict[key] = merge_dicts(dict_1[key], dict_2[key])
 
-            # Booleans (has to be the type Bool, not just a 0 or 1)
-            elif isinstance(dict_1[key], bool) and isinstance(dict_2[key], bool):
-                new_dict[key] = dict_1[key] * dict_2[key]
-
             else:
                 print(
                     "Object types {},{} not supported".format(
                         type(dict_1[key]), type(dict_2[key])
                     )
                 )
+                raise ValueError
 
     #
     return new_dict
 
 
+def extract_ensemble_json_from_string(binary_c_output: str) -> dict:
+    """
+    Function to extract the ensemble_json information from a raw binary_c output string
+
+    Args:
+        binary_c_output: raw binary_c output string
+
+    Returns:
+        json dictionary with the parsed ENSEMBLE_JSON data
+    """
+
+    json = None
+
+    try:
+        ensemble_jsons_strings = [
+            line
+            for line in binary_c_output.splitlines()
+            if line.startswith("ENSEMBLE_JSON")
+        ]
+
+        json = handle_ensemble_string_to_json(
+            ensemble_jsons_strings[0][len("ENSEMBLE_JSON ") :]
+        )
+
+        if len(ensemble_jsons_strings) > 1:
+            verbose_print(
+                "Warning: There is more than one line starting with ENSEMBLE_JSON. Taking the first, but you should check this out.",
+                1,
+                0,
+            )
+    except IndexError:
+        verbose_print(
+            "Error: Couldn't extract the ensemble information from the output string",
+            0,
+            0,
+        )
+
+    return json
+
+
 class binarycDecoder(json.JSONDecoder):
     """
     Custom decoder to transform the numbers that are strings to actual floats
     """
 
     def decode(self, s):
+        """
+        Entry point function for decoding
+        """
+
         result = super().decode(
             s
         )  # result = super(Decoder, self).decode(s) for Python 2.x
@@ -1201,7 +1304,14 @@ class binarycDecoder(json.JSONDecoder):
 
 
 class BinaryCEncoder(json.JSONEncoder):
+    """
+    Encoding class function to attempt to convert things to strings.
+    """
+
     def default(self, o):
+        """
+        Converting function. Well, could be more precise. look at the json module
+        """
         try:
             str_repr = str(o)
         except TypeError:
