@@ -49,7 +49,7 @@ grid_options_defaults_dict = {
     "_binary_c_config_executable": os.path.join(
         os.environ["BINARY_C"], "binary_c-config"
     ),  # TODO: make this more robust
-    "_binary_c_dir": os.environ["BINARYC_DIR"],
+    "_binary_c_dir": os.environ["BINARY_C"],
     ##########################
     # Custom logging
     ##########################
