@@ -44,8 +44,8 @@ Printf("MASS_PLOTTING %30.12e %g %g %g %g\\n",
     stardata->model.time, // 1
     
     // masses
-    stardata->star[0].pms_mass, // 
-    stardata->star[1].pms_mass,  // 
+    stardata->common.zero_age.mass[0], //
+    stardata->common.zero_age.mass[1], //
 
     stardata->star[0].mass,
     stardata->star[1].mass
@@ -80,13 +80,17 @@ Printf("HR_PLOTTING %30.12e %d %d %g %g %g %g %g %g\\n",
     stardata->star[1].radius,     // 7
 
     // masses
-    stardata->star[0].pms_mass, // 8
-    stardata->star[1].pms_mass  // 9
+    stardata->common.zero_age.mass[0], // 8
+    stardata->common.zero_age.mass[1]  // 9
     );
 """
 
 
 def color_by_index(row, column, colors):
+    """
+    Function that returns a color based on row and column information. Used to color the stellar types
+    """
+
     return colors[int(row[column])]
 
 
@@ -235,6 +239,8 @@ def plot_orbit(df, show_stellar_types: bool = False, show_plot: bool = True):
         - Separation
         - eccentricity
 
+    TODO: fix stellar_types plot
+
     Args:
         df: pandas dataframe with the required columns
         show_stellar_types: whether to color code the tracks and show the stellar types
@@ -301,6 +307,8 @@ def plot_masses(df, show_stellar_types: bool = False, show_plot: bool = True):
         - pms total mass
         - (maybe?) core and env masses
 
+    TODO: fix stellar_types plot
+
     Args:
         df: pandas dataframe with the required columns
         show_stellar_types: whether to color code the tracks and show the stellar types
@@ -522,7 +530,7 @@ def plot_system(plot_type, **kwargs):
         plot_type: string input should be one of ['mass_evolution', 'orbit_evolution', 'hr_diagram'].
             Input will be matched against this, and then go through a dictionary to pick the correct plotting function.
 
-        return_fig: boolean whether to return the fig object instead of plotting the plot
+        show_plot: boolean whether to show the plot. If False it returns the figure object
             (makes so that you can customize it)
 
         show_stellar_types: whether to plot the stellar type evolution on a second pane.
@@ -536,7 +544,7 @@ def plot_system(plot_type, **kwargs):
     """
 
     # set defaults and options
-    return_fig = False
+    show_plot = False
     show_stellar_types = False
 
     plot_types_dict = {
