@@ -34,7 +34,7 @@ def calc_period_from_sep(
         sep: Separation in solar radii
 
     Returns:
-        period in years
+        period in days
     """
 
     return YEARDY * (sep / AURSUN) * math.sqrt(sep / (AURSUN * (M1 + M2)))
@@ -46,8 +46,6 @@ def calc_sep_from_period(
     """
     Calculate separation from period.
 
-    TODO: check whether this is still correct
-
     Args:
         M1: Primary mass in solar mass
         M2: Secondary mass in solar mass
@@ -68,7 +66,7 @@ def roche_lobe(q: Union[int, float]) -> Union[int, float]:
     # TODO: check whether the logs are correct
 
     Args:
-        q: mass ratio of the binary (secondary/primary)
+        q: mass ratio of the binary (secondary/primary). If you input: q = mass_accretor/mass_donor, you will get the rochelobe radius of the accretor. And vice versa for the donor.
 
     Returns:
         Roche lobe radius in units of the separation
@@ -82,6 +80,8 @@ def ragb(m: Union[int, float], z: Union[int, float]) -> Union[int, float]:
     """
     Function to calculate radius of a star in units of solar radii at first thermal pulse as a function of mass (Z=0.02 only, but also good for Z=0.0001)
 
+    TODO: ask rob about this function
+
     Args:
         m: mass of star in units of solar mass
         z: metallicity of star
@@ -93,7 +93,7 @@ def ragb(m: Union[int, float], z: Union[int, float]) -> Union[int, float]:
     return m * 40.0 + 20.0
 
 
-def zams_collission(
+def zams_collision(
     m1: Union[int, float],
     m2: Union[int, float],
     sep: Union[int, float],
